From e30cdbf6812febe2b38e8d22020c2fc352f28638 Mon Sep 17 00:00:00 2001
From: Rosie Le Faive <lefaive@gmail.com>
Date: Fri, 8 Mar 2024 09:44:50 -0400
Subject: [PATCH 01/11] Update testing drupal and php versions

---
 .github/workflows/build-2.x.yml | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/.github/workflows/build-2.x.yml b/.github/workflows/build-2.x.yml
index 2ab3a539..4750ba4d 100644
--- a/.github/workflows/build-2.x.yml
+++ b/.github/workflows/build-2.x.yml
@@ -23,10 +23,10 @@ jobs:
     strategy:
       fail-fast: false
       matrix:
-        php-versions: ["8.1", "8.2"]
+        php-versions: ["8.1", "8.2", "8.3"]
         # test-suite functional-javascript will appear to pass but will skip tests; missing chromedriver.
         test-suite: ["kernel", "functional", "functional-javascript"]
-        drupal-version: ["10.0.x", "10.1.x", "10.2.x-dev"]
+        drupal-version: ["10.1.x", "10.2.x", "10.3.x-dev"]
         mysql: ["8.0"]
         allowed_failure: [false]
 

From 3784def28765a08f6df616aa9fb91731000dccd5 Mon Sep 17 00:00:00 2001
From: Rosie Le Faive <lefaive@gmail.com>
Date: Fri, 8 Mar 2024 11:03:10 -0400
Subject: [PATCH 02/11] Tests use strings not translateable markup to select
 interface buttons.

---
 .../src/Functional/GenerateAudioDerivativeTest.php   |  6 +++---
 .../src/Functional/GenerateImageDerivativeTest.php   |  6 +++---
 .../src/Functional/GenerateVideoDerivativeTest.php   |  6 +++---
 tests/src/Functional/ContentEntityTypeTest.php       |  2 +-
 tests/src/Functional/DerivativeReactionTest.php      |  2 +-
 tests/src/Functional/EmitNodeEventTest.php           |  2 +-
 tests/src/Functional/EntityBundleTest.php            |  2 +-
 .../src/Functional/FormDisplayAlterReactionTest.php  |  2 +-
 tests/src/Functional/IndexingTest.php                |  2 +-
 tests/src/Functional/IslandoraSettingsFormTest.php   | 10 +++++-----
 .../Functional/JsonldSelfReferenceReactionTest.php   |  2 +-
 tests/src/Functional/JsonldTypeAlterReactionTest.php | 12 ++++++------
 12 files changed, 27 insertions(+), 27 deletions(-)

diff --git a/modules/islandora_audio/tests/src/Functional/GenerateAudioDerivativeTest.php b/modules/islandora_audio/tests/src/Functional/GenerateAudioDerivativeTest.php
index 6b85cd1b..094a7856 100644
--- a/modules/islandora_audio/tests/src/Functional/GenerateAudioDerivativeTest.php
+++ b/modules/islandora_audio/tests/src/Functional/GenerateAudioDerivativeTest.php
@@ -40,7 +40,7 @@ class GenerateAudioDerivativeTest extends GenerateDerivativeTestBase {
     // Create an action to generate a audio derivative.
     $this->drupalGet('admin/config/system/actions');
     $this->getSession()->getPage()->findById("edit-action")->selectOption("Generate a audio derivative");
-    $this->getSession()->getPage()->pressButton($this->t('Create'));
+    $this->getSession()->getPage()->pressButton('Create');
     $this->assertSession()->statusCodeEquals(200);
 
     $this->getSession()->getPage()->fillField('edit-label', "Generate audio test derivative");
@@ -53,7 +53,7 @@ class GenerateAudioDerivativeTest extends GenerateDerivativeTestBase {
     $this->getSession()->getPage()->fillField('edit-args', "-f mp3");
     $this->getSession()->getPage()->fillField('edit-scheme', "public");
     $this->getSession()->getPage()->fillField('edit-path', "derp.mov");
-    $this->getSession()->getPage()->pressButton($this->t('Save'));
+    $this->getSession()->getPage()->pressButton('Save');
     $this->assertSession()->statusCodeEquals(200);
 
     // Create a context and add the action as a derivative reaction.
@@ -69,7 +69,7 @@ class GenerateAudioDerivativeTest extends GenerateDerivativeTestBase {
       'field_media_use[0][target_id]' => $this->preservationMasterTerm->label(),
     ];
     $this->drupalGet('media/add/' . $this->testMediaType->id());
-    $this->submitForm($values, $this->t('Save'));
+    $this->submitForm($values, 'Save');
 
     $expected = [
       'source_uri' => 'test_file.txt',
diff --git a/modules/islandora_image/tests/src/Functional/GenerateImageDerivativeTest.php b/modules/islandora_image/tests/src/Functional/GenerateImageDerivativeTest.php
index 44cdda58..17c1beae 100644
--- a/modules/islandora_image/tests/src/Functional/GenerateImageDerivativeTest.php
+++ b/modules/islandora_image/tests/src/Functional/GenerateImageDerivativeTest.php
@@ -42,7 +42,7 @@ class GenerateImageDerivativeTest extends GenerateDerivativeTestBase {
     // Create an action to generate a jpeg thumbnail.
     $this->drupalGet('admin/config/system/actions');
     $this->getSession()->getPage()->findById("edit-action")->selectOption("Generate an image derivative");
-    $this->getSession()->getPage()->pressButton($this->t('Create'));
+    $this->getSession()->getPage()->pressButton('Create');
     $this->assertSession()->statusCodeEquals(200);
 
     $this->getSession()->getPage()->fillField('edit-label', "Generate image test derivative");
@@ -55,7 +55,7 @@ class GenerateImageDerivativeTest extends GenerateDerivativeTestBase {
     $this->getSession()->getPage()->fillField('edit-args', "-thumbnail 20x20");
     $this->getSession()->getPage()->fillField('edit-scheme', "public");
     $this->getSession()->getPage()->fillField('edit-path', "derp.jpeg");
-    $this->getSession()->getPage()->pressButton($this->t('Save'));
+    $this->getSession()->getPage()->pressButton('Save');
     $this->assertSession()->statusCodeEquals(200);
 
     // Create a context and add the action as a derivative reaction.
@@ -71,7 +71,7 @@ class GenerateImageDerivativeTest extends GenerateDerivativeTestBase {
       'field_media_use[0][target_id]' => $this->preservationMasterTerm->label(),
     ];
     $this->drupalGet('media/add/' . $this->testMediaType->id());
-    $this->submitForm($values, $this->t('Save'));
+    $this->submitForm($values, 'Save');
 
     $expected = [
       'source_uri' => 'test_file.txt',
diff --git a/modules/islandora_video/tests/src/Functional/GenerateVideoDerivativeTest.php b/modules/islandora_video/tests/src/Functional/GenerateVideoDerivativeTest.php
index de06ba2f..2f79e18e 100644
--- a/modules/islandora_video/tests/src/Functional/GenerateVideoDerivativeTest.php
+++ b/modules/islandora_video/tests/src/Functional/GenerateVideoDerivativeTest.php
@@ -37,7 +37,7 @@ class GenerateVideoDerivativeTest extends GenerateDerivativeTestBase {
     // Create an action to generate a jpeg thumbnail.
     $this->drupalGet('admin/config/system/actions');
     $this->getSession()->getPage()->findById("edit-action")->selectOption("Generate a video derivative");
-    $this->getSession()->getPage()->pressButton($this->t('Create'));
+    $this->getSession()->getPage()->pressButton('Create');
     $this->assertSession()->statusCodeEquals(200);
 
     $this->getSession()->getPage()->fillField('edit-label', "Generate video test derivative");
@@ -50,7 +50,7 @@ class GenerateVideoDerivativeTest extends GenerateDerivativeTestBase {
     $this->getSession()->getPage()->fillField('edit-args', "-f mp4");
     $this->getSession()->getPage()->fillField('edit-scheme', "public");
     $this->getSession()->getPage()->fillField('edit-path', "derp.mov");
-    $this->getSession()->getPage()->pressButton($this->t('Save'));
+    $this->getSession()->getPage()->pressButton('Save');
     $this->assertSession()->statusCodeEquals(200);
 
     // Create a context and add the action as a derivative reaction.
@@ -66,7 +66,7 @@ class GenerateVideoDerivativeTest extends GenerateDerivativeTestBase {
       'field_media_use[0][target_id]' => $this->preservationMasterTerm->label(),
     ];
     $this->drupalGet('media/add/' . $this->testMediaType->id());
-    $this->submitForm($values, $this->t('Save'));
+    $this->submitForm($values, 'Save');
 
     $expected = [
       'source_uri' => 'test_file.txt',
diff --git a/tests/src/Functional/ContentEntityTypeTest.php b/tests/src/Functional/ContentEntityTypeTest.php
index 5ed22948..b753852a 100644
--- a/tests/src/Functional/ContentEntityTypeTest.php
+++ b/tests/src/Functional/ContentEntityTypeTest.php
@@ -39,7 +39,7 @@ class ContentEntityTypeTest extends IslandoraFunctionalTestBase {
     $this->addCondition('test', 'content_entity_type');
     $this->getSession()->getPage()->checkField("edit-conditions-content-entity-type-types-node");
     $this->getSession()->getPage()->findById("edit-conditions-content-entity-type-context-mapping-node")->selectOption("@node.node_route_context:node");
-    $this->getSession()->getPage()->pressButton($this->t('Save and continue'));
+    $this->getSession()->getPage()->pressButton('Save and continue');
     $this->addPresetReaction('test', 'index', 'hello_world');
 
     // Create a new node confirm Hello World! is printed to the screen.
diff --git a/tests/src/Functional/DerivativeReactionTest.php b/tests/src/Functional/DerivativeReactionTest.php
index 00e0e5ae..7c0cedb3 100644
--- a/tests/src/Functional/DerivativeReactionTest.php
+++ b/tests/src/Functional/DerivativeReactionTest.php
@@ -53,7 +53,7 @@ class DerivativeReactionTest extends IslandoraFunctionalTestBase {
       'field_media_of[0][target_id]' => 'Test Node',
     ];
     $this->drupalGet('media/add/' . $this->testMediaType->id());
-    $this->submitForm($values, $this->t('Save'));
+    $this->submitForm($values, 'Save');
 
     // field_media_of is set and there's a file, so derivatives should fire.
     $this->assertSession()->pageTextContains("Hello World!");
diff --git a/tests/src/Functional/EmitNodeEventTest.php b/tests/src/Functional/EmitNodeEventTest.php
index 83f062ae..3ebcc6dd 100644
--- a/tests/src/Functional/EmitNodeEventTest.php
+++ b/tests/src/Functional/EmitNodeEventTest.php
@@ -44,7 +44,7 @@ class EmitNodeEventTest extends IslandoraFunctionalTestBase {
     $this->addCondition('test', 'content_entity_type');
     $this->getSession()->getPage()->checkField("edit-conditions-content-entity-type-types-node");
     $this->getSession()->getPage()->findById("edit-conditions-content-entity-type-context-mapping-node")->selectOption("@node.node_route_context:node");
-    $this->getSession()->getPage()->pressButton($this->t('Save and continue'));
+    $this->getSession()->getPage()->pressButton('Save and continue');
 
     $this->addPresetReaction('test', 'index', $action_id);
     $this->assertSession()->statusCodeEquals(200);
diff --git a/tests/src/Functional/EntityBundleTest.php b/tests/src/Functional/EntityBundleTest.php
index bde1ee40..27183826 100644
--- a/tests/src/Functional/EntityBundleTest.php
+++ b/tests/src/Functional/EntityBundleTest.php
@@ -27,7 +27,7 @@ class EntityBundleTest extends IslandoraFunctionalTestBase {
     $this->addCondition('test', 'islandora_entity_bundle');
     $this->getSession()->getPage()->checkField("edit-conditions-islandora-entity-bundle-bundles-test-type");
     $this->getSession()->getPage()->findById("edit-conditions-islandora-entity-bundle-context-mapping-node")->selectOption("@node.node_route_context:node");
-    $this->getSession()->getPage()->pressButton($this->t('Save and continue'));
+    $this->getSession()->getPage()->pressButton('Save and continue');
     $this->addPresetReaction('test', 'index', 'hello_world');
 
     // Create a new test_type confirm Hello World! is printed to the screen.
diff --git a/tests/src/Functional/FormDisplayAlterReactionTest.php b/tests/src/Functional/FormDisplayAlterReactionTest.php
index d394b728..fe70aa64 100644
--- a/tests/src/Functional/FormDisplayAlterReactionTest.php
+++ b/tests/src/Functional/FormDisplayAlterReactionTest.php
@@ -49,7 +49,7 @@ class FormDisplayAlterReactionTest extends IslandoraFunctionalTestBase {
 
     $this->drupalGet("admin/structure/context/test/reaction/add/form_display_alter");
     $this->getSession()->getPage()->findById("edit-reactions-form-display-alter-mode")->selectOption('node.secondary');
-    $this->getSession()->getPage()->pressButton($this->t('Save and continue'));
+    $this->getSession()->getPage()->pressButton('Save and continue');
     $this->assertSession()->statusCodeEquals(200);
 
     drupal_flush_all_caches();
diff --git a/tests/src/Functional/IndexingTest.php b/tests/src/Functional/IndexingTest.php
index ff215281..cf2dbb66 100644
--- a/tests/src/Functional/IndexingTest.php
+++ b/tests/src/Functional/IndexingTest.php
@@ -66,7 +66,7 @@ class IndexingTest extends IslandoraFunctionalTestBase {
     $this->drupalGet("$url/delete");
 
     // Delete the node.
-    $this->submitForm([], $this->t('Delete'));
+    $this->submitForm([], 'Delete');
     $this->assertSession()->statusCodeEquals(200);
 
     // Confirm Goodbye, Cruel World! is printed to the screen.
diff --git a/tests/src/Functional/IslandoraSettingsFormTest.php b/tests/src/Functional/IslandoraSettingsFormTest.php
index 80a327af..18bfcafb 100644
--- a/tests/src/Functional/IslandoraSettingsFormTest.php
+++ b/tests/src/Functional/IslandoraSettingsFormTest.php
@@ -38,23 +38,23 @@ class IslandoraSettingsFormTest extends IslandoraFunctionalTestBase {
     $this->assertSession()->fieldValueEquals('edit-jwt-expiry', '+2 hour');
     $this->drupalGet('/admin/config/islandora/core');
     // Blank is not allowed.
-    $this->submitForm(['edit-jwt-expiry' => ""], $this->t('Save configuration'));
+    $this->submitForm(['edit-jwt-expiry' => ""], 'Save configuration');
     $this->assertSession()->pageTextContainsOnce('"" is not a valid time or interval expression.');
     $this->drupalGet('/admin/config/islandora/core');
     // Negative is not allowed.
-    $this->submitForm(['edit-jwt-expiry' => "-2 hours"], $this->t('Save configuration'));
+    $this->submitForm(['edit-jwt-expiry' => "-2 hours"], 'Save configuration');
     $this->assertSession()->pageTextContainsOnce('Time or interval expression cannot be negative');
     $this->drupalGet('/admin/config/islandora/core');
     // Must include an integer value.
-    $this->submitForm(['edit-jwt-expiry' => "last hour"], $this->t('Save configuration'));
+    $this->submitForm(['edit-jwt-expiry' => "last hour"], 'Save configuration');
     $this->assertSession()->pageTextContainsOnce('No numeric interval specified, for example "1 day"');
     $this->drupalGet('/admin/config/islandora/core');
     // Must have an accepted interval.
-    $this->submitForm(['edit-jwt-expiry' => "1 fortnight"], $this->t('Save configuration'));
+    $this->submitForm(['edit-jwt-expiry' => "1 fortnight"], 'Save configuration');
     $this->assertSession()->pageTextContainsOnce('No time interval found, please include one of');
     $this->drupalGet('/admin/config/islandora/core');
     // Test a valid setting.
-    $this->submitForm(['edit-jwt-expiry' => "2 weeks"], $this->t('Save configuration'));
+    $this->submitForm(['edit-jwt-expiry' => "2 weeks"], 'Save configuration');
     $this->assertSession()->pageTextContainsOnce('The configuration options have been saved.');
 
   }
diff --git a/tests/src/Functional/JsonldSelfReferenceReactionTest.php b/tests/src/Functional/JsonldSelfReferenceReactionTest.php
index 1b4e24ec..c8acfcc9 100644
--- a/tests/src/Functional/JsonldSelfReferenceReactionTest.php
+++ b/tests/src/Functional/JsonldSelfReferenceReactionTest.php
@@ -60,7 +60,7 @@ class JsonldSelfReferenceReactionTest extends IslandoraFunctionalTestBase {
 
     $this->postNodeAddForm('test_type',
       ['title[0][value]' => 'Test Node'],
-      $this->t('Save'));
+      'Save');
     $this->assertSession()->pageTextContains("Test Node");
     $url = $this->getUrl();
 
diff --git a/tests/src/Functional/JsonldTypeAlterReactionTest.php b/tests/src/Functional/JsonldTypeAlterReactionTest.php
index 75ae41dd..5ab9037c 100644
--- a/tests/src/Functional/JsonldTypeAlterReactionTest.php
+++ b/tests/src/Functional/JsonldTypeAlterReactionTest.php
@@ -32,7 +32,7 @@ class JsonldTypeAlterReactionTest extends JsonldSelfReferenceReactionTest {
         'label' => 'Typed Predicate',
         'field_name' => 'type_predicate',
       ], 'Save and continue');
-      $this->submitForm([], $this->t('Save field settings'));
+      $this->submitForm([], 'Save field settings');
     }
     else {
       $this->getSession()->getPage()->selectFieldOption('new_storage_type', 'plain_text');
@@ -46,7 +46,7 @@ class JsonldTypeAlterReactionTest extends JsonldSelfReferenceReactionTest {
         'new_storage_type' => 'plain_text',
         'label' => 'Typed Predicate',
         'field_name' => 'type_predicate',
-      ], $this->t('Continue'));
+      ], 'Continue');
 
       // Now we can proceed, selecting the plain text (i.e. string)
       // for the second element now that the element is displayed after
@@ -57,16 +57,16 @@ class JsonldTypeAlterReactionTest extends JsonldSelfReferenceReactionTest {
         'label' => 'Typed Predicate',
         'field_name' => 'type_predicate',
         'group_field_options_wrapper' => 'string',
-      ], $this->t('Continue'));
+      ], 'Continue');
     }
-    $this->submitForm([], $this->t('Save settings'));
+    $this->submitForm([], 'Save settings');
     $this->assertSession()->responseContains('field_type_predicate');
 
     // Add the test node.
     $this->postNodeAddForm('test_type', [
       'title[0][value]' => 'Test Node',
       'field_type_predicate[0][value]' => 'schema:Organization',
-    ], $this->t('Save'));
+    ], 'Save');
     $this->assertSession()->pageTextContains("Test Node");
     $url = $this->getUrl();
 
@@ -103,7 +103,7 @@ class JsonldTypeAlterReactionTest extends JsonldSelfReferenceReactionTest {
     $this->addCondition('test', 'islandora_entity_bundle');
     $this->getSession()->getPage()->checkField("edit-conditions-islandora-entity-bundle-bundles-test-type");
     $this->getSession()->getPage()->findById("edit-conditions-islandora-entity-bundle-context-mapping-node")->selectOption("@node.node_route_context:node");
-    $this->getSession()->getPage()->pressButton($this->t('Save and continue'));
+    $this->getSession()->getPage()->pressButton('Save and continue');
 
     // The first time a Context is saved, you need to clear the cache.
     // Subsequent changes to the context don't need a cache rebuild, though.

From 89261c17aefa7c2b6110de57c4f0814e0c572cfc Mon Sep 17 00:00:00 2001
From: Rosie Le Faive <lefaive@gmail.com>
Date: Fri, 8 Mar 2024 11:06:22 -0400
Subject: [PATCH 03/11] Add some forgotten translateable markup.

---
 tests/src/Functional/ContentEntityTypeTest.php       | 2 +-
 tests/src/Functional/DerivativeReactionTest.php      | 4 ++--
 tests/src/Functional/EmitNodeEventTest.php           | 4 ++--
 tests/src/Functional/IslandoraFunctionalTestBase.php | 2 +-
 tests/src/Functional/ViewModeAlterReactionTest.php   | 2 +-
 5 files changed, 7 insertions(+), 7 deletions(-)

diff --git a/tests/src/Functional/ContentEntityTypeTest.php b/tests/src/Functional/ContentEntityTypeTest.php
index b753852a..2fa9b574 100644
--- a/tests/src/Functional/ContentEntityTypeTest.php
+++ b/tests/src/Functional/ContentEntityTypeTest.php
@@ -53,7 +53,7 @@ class ContentEntityTypeTest extends IslandoraFunctionalTestBase {
       'files[field_media_file_0]' => __DIR__ . '/../../fixtures/test_file.txt',
     ];
     $this->drupalGet('media/add/' . $this->testMediaType->id());
-    $this->submitForm($values, $this->t('Save'));
+    $this->submitForm($values, 'Save');
     $this->assertSession()->pageTextNotContains("Hello World!");
   }
 
diff --git a/tests/src/Functional/DerivativeReactionTest.php b/tests/src/Functional/DerivativeReactionTest.php
index 7c0cedb3..720b8a45 100644
--- a/tests/src/Functional/DerivativeReactionTest.php
+++ b/tests/src/Functional/DerivativeReactionTest.php
@@ -71,9 +71,9 @@ class DerivativeReactionTest extends IslandoraFunctionalTestBase {
       'files[field_media_file_0]' => __DIR__ . '/../../fixtures/test_file2.txt',
     ];
     $this->drupalGet($media_url . '/edit');
-    $this->getSession()->getPage()->pressButton($this->t('Remove'));
+    $this->getSession()->getPage()->pressButton('Remove');
     $this->getSession()->getPage()->fillField('files[field_media_file_0]', __DIR__ . '/../../fixtures/test_file2.txt');
-    $this->getSession()->getPage()->pressButton($this->t('Save'));
+    $this->getSession()->getPage()->pressButton('Save');
     $this->assertSession()->pageTextContains("Hello World!");
   }
 
diff --git a/tests/src/Functional/EmitNodeEventTest.php b/tests/src/Functional/EmitNodeEventTest.php
index 3ebcc6dd..a18ffbc8 100644
--- a/tests/src/Functional/EmitNodeEventTest.php
+++ b/tests/src/Functional/EmitNodeEventTest.php
@@ -68,7 +68,7 @@ class EmitNodeEventTest extends IslandoraFunctionalTestBase {
   protected function createEmitAction($entity_type, $event_type) {
     $this->drupalGet('admin/config/system/actions');
     $this->getSession()->getPage()->findById("edit-action")->selectOption("Emit a $entity_type event to a queue/topic");
-    $this->getSession()->getPage()->pressButton($this->t('Create'));
+    $this->getSession()->getPage()->pressButton('Create');
     $this->assertSession()->statusCodeEquals(200);
 
     $action_id = "emit_" . $entity_type . "_" . lcfirst($event_type);
@@ -76,7 +76,7 @@ class EmitNodeEventTest extends IslandoraFunctionalTestBase {
     $this->getSession()->getPage()->fillField('edit-id', $action_id);
     $this->getSession()->getPage()->fillField('edit-queue', "emit-$entity_type-" . lcfirst($event_type));
     $this->getSession()->getPage()->findById("edit-event")->selectOption($event_type);
-    $this->getSession()->getPage()->pressButton($this->t('Save'));
+    $this->getSession()->getPage()->pressButton('Save');
     $this->assertSession()->statusCodeEquals(200);
 
     return $action_id;
diff --git a/tests/src/Functional/IslandoraFunctionalTestBase.php b/tests/src/Functional/IslandoraFunctionalTestBase.php
index 016788d0..b4c0bc95 100644
--- a/tests/src/Functional/IslandoraFunctionalTestBase.php
+++ b/tests/src/Functional/IslandoraFunctionalTestBase.php
@@ -306,7 +306,7 @@ EOD;
       ->getPage()
       ->findById("edit-reactions-$reaction_type-actions")
       ->selectOption($action_id);
-    $this->getSession()->getPage()->pressButton($this->t('Save and continue'));
+    $this->getSession()->getPage()->pressButton('Save and continue');
     $this->assertSession()->statusCodeEquals(200);
   }
 
diff --git a/tests/src/Functional/ViewModeAlterReactionTest.php b/tests/src/Functional/ViewModeAlterReactionTest.php
index 19660bda..90441402 100644
--- a/tests/src/Functional/ViewModeAlterReactionTest.php
+++ b/tests/src/Functional/ViewModeAlterReactionTest.php
@@ -75,7 +75,7 @@ class ViewModeAlterReactionTest extends IslandoraFunctionalTestBase {
 
     $this->drupalGet("admin/structure/context/test/reaction/add/view_mode_alter");
     $this->getSession()->getPage()->findById("edit-reactions-view-mode-alter-mode")->selectOption('node.teaser');
-    $this->getSession()->getPage()->pressButton($this->t('Save and continue'));
+    $this->getSession()->getPage()->pressButton('Save and continue');
     $this->assertSession()->statusCodeEquals(200);
 
     drupal_flush_all_caches();

From 9f2277fc51c5e29bea3730e2bef3a0432f20b800 Mon Sep 17 00:00:00 2001
From: Rosie Le Faive <lefaive@gmail.com>
Date: Fri, 8 Mar 2024 11:22:03 -0400
Subject: [PATCH 04/11] Exclude PHP 8.3 with Drupal 10.1.

---
 .github/workflows/build-2.x.yml | 3 +++
 1 file changed, 3 insertions(+)

diff --git a/.github/workflows/build-2.x.yml b/.github/workflows/build-2.x.yml
index 4750ba4d..c5d9d66b 100644
--- a/.github/workflows/build-2.x.yml
+++ b/.github/workflows/build-2.x.yml
@@ -29,6 +29,9 @@ jobs:
         drupal-version: ["10.1.x", "10.2.x", "10.3.x-dev"]
         mysql: ["8.0"]
         allowed_failure: [false]
+        exclude:
+          - php-versions: "8.3"
+            drupal-version: "10.1.x"
 
 
     name: PHP ${{ matrix.php-versions }} | drupal ${{ matrix.drupal-version }} | mysql ${{ matrix.mysql }} | test-suite ${{ matrix.test-suite }}

From 13bc15ea43659824f2397a43914efe462a8dd546 Mon Sep 17 00:00:00 2001
From: Rosie Le Faive <lefaive@gmail.com>
Date: Fri, 8 Mar 2024 16:50:50 -0400
Subject: [PATCH 05/11] Last attempt to not pass translatables as button
 labels.

---
 tests/src/Functional/IslandoraFunctionalTestBase.php | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/tests/src/Functional/IslandoraFunctionalTestBase.php b/tests/src/Functional/IslandoraFunctionalTestBase.php
index b4c0bc95..1ad8081d 100644
--- a/tests/src/Functional/IslandoraFunctionalTestBase.php
+++ b/tests/src/Functional/IslandoraFunctionalTestBase.php
@@ -315,7 +315,7 @@ EOD;
    */
   protected function postNodeAddForm($bundle_id, $values, $button_text) {
     $this->drupalGet("node/add/$bundle_id");
-    $this->submitForm($values, $this->t('@text', ['@text' => $button_text]));
+    $this->submitForm($values, $button_text);
     $this->assertSession()->statusCodeEquals(200);
   }
 
@@ -324,7 +324,7 @@ EOD;
    */
   protected function postTermAddForm($taxomony_id, $values, $button_text) {
     $this->drupalGet("admin/structure/taxonomy/manage/$taxomony_id/add");
-    $this->submitForm($values, $this->t('@text', ['@text' => $button_text]));
+    $this->submitForm($values, $button_text);
     $this->assertSession()->statusCodeEquals(200);
   }
 
@@ -333,7 +333,7 @@ EOD;
    */
   protected function postEntityEditForm($entity_url, $values, $button_text) {
     $this->drupalGet("$entity_url/edit");
-    $this->submitForm($values, $this->t('@text', ['@text' => $button_text]));
+    $this->submitForm($values, $button_text);
     $this->assertSession()->statusCodeEquals(200);
   }
 

From 9ed3637339d4aaf1723f775cc9d009d12a3c2e2d Mon Sep 17 00:00:00 2001
From: Rosie Le Faive <lefaive@gmail.com>
Date: Wed, 3 Apr 2024 14:16:19 -0300
Subject: [PATCH 06/11] Update islandora.module (#1008)

---
 islandora.module | 1 +
 1 file changed, 1 insertion(+)

diff --git a/islandora.module b/islandora.module
index d3dfa01d..d715db52 100644
--- a/islandora.module
+++ b/islandora.module
@@ -615,6 +615,7 @@ function islandora_form_block_form_alter(&$form, FormStateInterface $form_state,
   unset($form['visibility']['media_is_islandora_media']);
   unset($form['visibility']['media_uses_filesystem']);
   unset($form['visibility']['node_had_namespace']);
+  unset($form['visibility']['node_has_ancestor']);
   unset($form['visibility']['node_has_parent']);
   unset($form['visibility']['node_has_term']);
   unset($form['visibility']['node_is_islandora_object']);

From a2c31fcaad87d753ca6725fef47fde39579c3342 Mon Sep 17 00:00:00 2001
From: Rosie Le Faive <lefaive@gmail.com>
Date: Wed, 3 Apr 2024 14:47:01 -0300
Subject: [PATCH 07/11] @adam-vessey's fix for drupalGet headers.

---
 tests/src/Functional/LinkHeaderTest.php | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/tests/src/Functional/LinkHeaderTest.php b/tests/src/Functional/LinkHeaderTest.php
index 98b36c68..78dd6c99 100644
--- a/tests/src/Functional/LinkHeaderTest.php
+++ b/tests/src/Functional/LinkHeaderTest.php
@@ -142,7 +142,7 @@ class LinkHeaderTest extends IslandoraFunctionalTestBase {
     $media_url = $this->media->toUrl('canonical', ['absolute' => TRUE])->toString();
 
     // Perform a GET request as anonymous.
-    $this->drupalGet($media_url, [], ['Cache-Control: no-cache']);
+    $this->drupalGet($media_url, [], ['Cache-Control' => 'no-cache']);
     // Check link headers.
     $this->assertTrue(
       $this->validateLinkHeaderWithUrl('describes', $file_url, '', 'text/plain') == 1,
@@ -174,7 +174,7 @@ class LinkHeaderTest extends IslandoraFunctionalTestBase {
     $this->drupalLogin($account);
 
     // Perform a GET request with update media permissions.
-    $this->drupalGet($media_url, [], ['Cache-Control: no-cache']);
+    $this->drupalGet($media_url, [], ['Cache-Control' => 'no-cache']);
 
     // Check link headers again, the edit-media link header should be present.
     $this->assertTrue(

From 95c2d6c0c9970f48f44b579d19f76a3f87ed8767 Mon Sep 17 00:00:00 2001
From: Rosie Le Faive <lefaive@gmail.com>
Date: Thu, 4 Apr 2024 10:04:05 -0300
Subject: [PATCH 09/11] Syntax.

---
 tests/src/Functional/JsonldTypeAlterReactionTest.php | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/tests/src/Functional/JsonldTypeAlterReactionTest.php b/tests/src/Functional/JsonldTypeAlterReactionTest.php
index 90036048..edefd77a 100644
--- a/tests/src/Functional/JsonldTypeAlterReactionTest.php
+++ b/tests/src/Functional/JsonldTypeAlterReactionTest.php
@@ -34,7 +34,7 @@ class JsonldTypeAlterReactionTest extends JsonldSelfReferenceReactionTest {
       ], 'Save and continue');
       $this->submitForm([], 'Save field settings');
     }
-    elseif (version_compare(\Drupal::VERSION, '10.3.x-dev', 'lt'){
+    elseif (version_compare(\Drupal::VERSION, '10.3.x-dev', 'lt')) {
       $this->getSession()->getPage()->selectFieldOption('new_storage_type', 'plain_text');
       // For Drupal 10.2, we first need to submit the form with the elements
       // displayed on initial page load. The form is using AJAX to send a

From 263666f5fcf305e0fe8ee86fda03959e4db4bde7 Mon Sep 17 00:00:00 2001
From: Rosie Le Faive <lefaive@gmail.com>
Date: Thu, 4 Apr 2024 14:51:20 -0300
Subject: [PATCH 10/11] Remove new_storage_type from form part 2.

---
 tests/src/Functional/JsonldTypeAlterReactionTest.php | 1 -
 1 file changed, 1 deletion(-)

diff --git a/tests/src/Functional/JsonldTypeAlterReactionTest.php b/tests/src/Functional/JsonldTypeAlterReactionTest.php
index edefd77a..6ac70d7d 100644
--- a/tests/src/Functional/JsonldTypeAlterReactionTest.php
+++ b/tests/src/Functional/JsonldTypeAlterReactionTest.php
@@ -72,7 +72,6 @@ class JsonldTypeAlterReactionTest extends JsonldSelfReferenceReactionTest {
       // the initial form submission.
       $this->getSession()->getPage()->selectFieldOption('group_field_options_wrapper', 'string');
       $this->submitForm([
-        'new_storage_type' => 'plain_text',
         'label' => 'Typed Predicate',
         'field_name' => 'type_predicate',
         'group_field_options_wrapper' => 'string',

From 9b2661696db027867061f237639167ed3684c6b5 Mon Sep 17 00:00:00 2001
From: Joe Corall <joe@libops.io>
Date: Fri, 19 Apr 2024 11:13:21 -0400
Subject: [PATCH 11/11] Add hOCR functionality (#1006)

* Add hOCR functionality
* Fix wording in Islandora IIIF View Style config form.
* Islandora IIIF: Attempt to fix broken config schema.
* Islandora IIIF: Remove labels from config schema.
* Islandora IIIF: Add labels to config schema items.
* Update IIIFManifest.php
* Move to memorized term lookup, instead of polluting method call.
* Deal explicitly with URIs, instead of attempting to put the entity in config.
* hocr Islandora IIIF: Add missing null check.

---------

Co-authored-by: Alexander O'Neill <alexander@born-digital.com>
Co-authored-by: Alexander O'Neill <aloneill@gmail.com>
Co-authored-by: Rosie Le Faive <lefaive@gmail.com>
Co-authored-by: Adam Vessey <adam@discoverygarden.ca>
---
 .../config/schema/islandora_iiif.schema.yml   |  12 ++
 .../src/Plugin/views/style/IIIFManifest.php   | 135 ++++++++++++++++--
 2 files changed, 136 insertions(+), 11 deletions(-)

diff --git a/modules/islandora_iiif/config/schema/islandora_iiif.schema.yml b/modules/islandora_iiif/config/schema/islandora_iiif.schema.yml
index 1f91450f..11fff4c7 100644
--- a/modules/islandora_iiif/config/schema/islandora_iiif.schema.yml
+++ b/modules/islandora_iiif/config/schema/islandora_iiif.schema.yml
@@ -17,5 +17,17 @@ views.style.iiif_manifest:
   mapping:
     iiif_tile_field:
       type: sequence
+      label: "Tile source field(s)"
       sequence:
         type: string
+    iiif_ocr_file_field:
+      type: sequence
+      label: "Structured OCR data file field"
+      sequence:
+        type: string
+    structured_text_term_uri:
+      type: string
+      label: "Structured text term"
+    search_endpoint:
+      type: string
+      label: "Search endpoint path"
diff --git a/modules/islandora_iiif/src/Plugin/views/style/IIIFManifest.php b/modules/islandora_iiif/src/Plugin/views/style/IIIFManifest.php
index 2fc8a431..f0aca47d 100644
--- a/modules/islandora_iiif/src/Plugin/views/style/IIIFManifest.php
+++ b/modules/islandora_iiif/src/Plugin/views/style/IIIFManifest.php
@@ -11,6 +11,8 @@ use Drupal\Core\Field\FieldItemInterface;
 use Drupal\Core\Form\FormStateInterface;
 use Drupal\Core\Messenger\MessengerInterface;
 use Drupal\Core\Url;
+use Drupal\islandora\IslandoraUtils;
+use Drupal\taxonomy\TermInterface;
 use Drupal\views\Plugin\views\style\StylePluginBase;
 use Drupal\views\ResultRow;
 use GuzzleHttp\Client;
@@ -35,6 +37,13 @@ use Symfony\Component\HttpFoundation\Request;
  */
 class IIIFManifest extends StylePluginBase {
 
+  /**
+   * Islandora utility functions.
+   *
+   * @var \Drupal\islandora\IslandoraUtils
+   */
+  protected $utils;
+
   /**
    * {@inheritdoc}
    */
@@ -108,10 +117,24 @@ class IIIFManifest extends StylePluginBase {
    */
   protected $moduleHandler;
 
+  /**
+   * Memoized structured text term.
+   *
+   * @var \Drupal\taxonomy\TermInterface|null
+   */
+  protected ?TermInterface $structuredTextTerm;
+
+  /**
+   * Flag to track if we _have_ attempted a lookup, as the value is nullable.
+   *
+   * @var bool
+   */
+  protected bool $structuredTextTermMemoized = FALSE;
+
   /**
    * {@inheritdoc}
    */
-  public function __construct(array $configuration, $plugin_id, $plugin_definition, SerializerInterface $serializer, Request $request, ImmutableConfig $iiif_config, EntityTypeManagerInterface $entity_type_manager, FileSystemInterface $file_system, Client $http_client, MessengerInterface $messenger, ModuleHandlerInterface $moduleHandler) {
+  public function __construct(array $configuration, $plugin_id, $plugin_definition, SerializerInterface $serializer, Request $request, ImmutableConfig $iiif_config, EntityTypeManagerInterface $entity_type_manager, FileSystemInterface $file_system, Client $http_client, MessengerInterface $messenger, ModuleHandlerInterface $moduleHandler, IslandoraUtils $utils) {
     parent::__construct($configuration, $plugin_id, $plugin_definition);
 
     $this->serializer = $serializer;
@@ -121,6 +144,7 @@ class IIIFManifest extends StylePluginBase {
     $this->fileSystem = $file_system;
     $this->httpClient = $http_client;
     $this->messenger = $messenger;
+    $this->utils = $utils;
     $this->moduleHandler = $moduleHandler;
   }
 
@@ -139,7 +163,8 @@ class IIIFManifest extends StylePluginBase {
       $container->get('file_system'),
       $container->get('http_client'),
       $container->get('messenger'),
-      $container->get('module_handler')
+      $container->get('module_handler'),
+      $container->get('islandora.utils')
     );
   }
 
@@ -217,6 +242,9 @@ class IIIFManifest extends StylePluginBase {
 
     $content_type = 'json';
 
+    // Add a search endpoint if one is defined.
+    $this->addSearchEndpoint($json, $url_components);
+
     // Give other modules a chance to alter the manifest.
     $this->moduleHandler->alter('islandora_iiif_manifest', $json, $this);
 
@@ -300,7 +328,7 @@ class IIIFManifest extends StylePluginBase {
             ],
           ];
 
-          if ($ocr_url = $this->getOcrUrl($entity, $row, $i)) {
+          if ($ocr_url = $this->getOcrUrl($entity)) {
             $tmp_canvas['seeAlso'] = [
               '@id' => $ocr_url,
               'format' => 'text/vnd.hocr+html',
@@ -380,30 +408,38 @@ class IIIFManifest extends StylePluginBase {
    *
    * @param \Drupal\Core\Entity\EntityInterface $entity
    *   The entity at the current row.
-   * @param \Drupal\views\ResultRow $row
-   *   Result row.
-   * @param int $delta
-   *   The delta in case there are multiple canvases on one media.
    *
    * @return string|false
    *   The absolute URL of the current row's structured text,
    *   or FALSE if none.
    */
-  protected function getOcrUrl(EntityInterface $entity, ResultRow $row, $delta) {
+  protected function getOcrUrl(EntityInterface $entity) {
     $ocr_url = FALSE;
     $iiif_ocr_file_field = !empty($this->options['iiif_ocr_file_field']) ? array_filter(array_values($this->options['iiif_ocr_file_field'])) : [];
     $ocrField = count($iiif_ocr_file_field) > 0 ? $this->view->field[$iiif_ocr_file_field[0]] : NULL;
     if ($ocrField) {
-      $ocr_entity = $ocrField->getEntity($row);
+      $ocr_entity = $entity;
       $ocr_field_name = $ocrField->definition['field_name'];
       if (!is_null($ocr_field_name)) {
         $ocrs = $ocr_entity->{$ocr_field_name};
-        $ocr = isset($ocrs[$delta]) ? $ocrs[$delta] : FALSE;
+        $ocr = $ocrs[0] ?? FALSE;
         if ($ocr) {
           $ocr_url = $ocr->entity->createFileUrl(FALSE);
         }
       }
     }
+    elseif ($structured_text_term = $this->getStructuredTextTerm()) {
+      $parent_node = $this->utils->getParentNode($entity);
+      $ocr_entity_array = $this->utils->getMediaReferencingNodeAndTerm($parent_node, $structured_text_term);
+      $ocr_entity_id = is_array($ocr_entity_array) ? array_shift($ocr_entity_array) : NULL;
+      $ocr_entity = $ocr_entity_id ? $this->entityTypeManager->getStorage('media')->load($ocr_entity_id) : NULL;
+      if ($ocr_entity) {
+        $ocr_file_source = $ocr_entity->getSource();
+        $ocr_fid = $ocr_file_source->getSourceFieldValue($ocr_entity);
+        $ocr_file = $this->entityTypeManager->getStorage('file')->load($ocr_fid);
+        $ocr_url = $ocr_file->createFileUrl(FALSE);
+      }
+    }
 
     return $ocr_url;
   }
@@ -448,6 +484,29 @@ class IIIFManifest extends StylePluginBase {
     return $options;
   }
 
+  /**
+   * Add the configured search endpoint to the manifest.
+   *
+   * @param array $json
+   *   The IIIF manifest.
+   * @param array $url_components
+   *   The search endpoint URL as array.
+   */
+  protected function addSearchEndpoint(array &$json, array $url_components) {
+    $url_base = $this->getRequest()->getSchemeAndHttpHost();
+    $hocr_search_path = $this->options['search_endpoint'];
+    $hocr_search_url = $url_base . '/' . ltrim($hocr_search_path, '/');
+
+    $hocr_search_url = str_replace('%node', $url_components[1], $hocr_search_url);
+
+    $json['service'][] = [
+      "@context" => "http://iiif.io/api/search/0/context.json",
+      "@id" => $hocr_search_url,
+      "profile" => "http://iiif.io/api/search/0/search",
+      "label" => t("Search inside this work"),
+    ];
+  }
+
   /**
    * {@inheritdoc}
    */
@@ -504,10 +563,27 @@ class IIIFManifest extends StylePluginBase {
       '#title' => $this->t('Structured OCR data file field'),
       '#type' => 'checkboxes',
       '#default_value' => $this->options['iiif_ocr_file_field'],
-      '#description' => $this->t('The source of structured OCR text for each entity.'),
+      '#description' => $this->t("If the hOCR is a field on the same entity as the image source  field above, select it here. If it's found in a related entity via the term below, leave this blank."),
       '#options' => $field_options,
       '#required' => FALSE,
     ];
+
+    $form['structured_text_term'] = [
+      '#type' => 'entity_autocomplete',
+      '#target_type' => 'taxonomy_term',
+      '#title' => $this->t('Structured OCR text term'),
+      '#default_value' => $this->getStructuredTextTerm(),
+      '#required' => FALSE,
+      '#description' => $this->t('Term indicating the media that holds structured text, such as hOCR, for the given object. Use this if the text is on a separate media from the tile source.'),
+    ];
+
+    $form['search_endpoint'] = [
+      '#type' => 'textfield',
+      '#title' => $this->t("Search endpoint path."),
+      '#description' => $this->t("If there is a search endpoint to search within the book that returns IIIF annotations, put it here. Use %node substitution where needed.<br>E.g., paged-content-search/%node"),
+      '#default_value' => $this->options['search_endpoint'],
+      '#required' => FALSE,
+    ];
   }
 
   /**
@@ -520,4 +596,41 @@ class IIIFManifest extends StylePluginBase {
     return ['json' => 'json'];
   }
 
+  /**
+   * Submit handler for options form.
+   *
+   * Used to store the structured text media term by URL instead of Ttid.
+   *
+   * @param array $form
+   *   The form.
+   * @param \Drupal\Core\Form\FormStateInterface $form_state
+   *   The form state object.
+   */
+  // @codingStandardsIgnoreStart
+  public function submitOptionsForm(&$form, FormStateInterface $form_state) {
+    // @codingStandardsIgnoreEnd
+    $style_options = $form_state->getValue('style_options');
+    $tid = $style_options['structured_text_term'];
+    unset($style_options['structured_text_term']);
+    $term = $this->entityTypeManager->getStorage('taxonomy_term')->load($tid);
+    $style_options['structured_text_term_uri'] = $this->utils->getUriForTerm($term);
+    $form_state->setValue('style_options', $style_options);
+    parent::submitOptionsForm($form, $form_state);
+  }
+
+  /**
+   * Get the structured text term.
+   *
+   * @return \Drupal\taxonomy\TermInterface|null
+   *   The term if it could be found; otherwise, NULL.
+   */
+  protected function getStructuredTextTerm() : ?TermInterface {
+    if (!$this->structuredTextTermMemoized) {
+      $this->structuredTextTermMemoized = TRUE;
+      $this->structuredTextTerm = $this->utils->getTermForUri($this->options['structured_text_term_uri']);
+    }
+
+    return $this->structuredTextTerm;
+  }
+
 }
From cde2c133e1b06f90f5f9cce949e32d4ab0bffb2a Mon Sep 17 00:00:00 2001
From: Rosie Le Faive <lefaive@gmail.com>
Date: Thu, 4 Apr 2024 09:56:45 -0300
Subject: [PATCH 08/11] Update tests for D10.3's new field selector form.

---
 .../JsonldTypeAlterReactionTest.php           | 27 ++++++++++++++++---
 1 file changed, 23 insertions(+), 4 deletions(-)

diff --git a/tests/src/Functional/JsonldTypeAlterReactionTest.php b/tests/src/Functional/JsonldTypeAlterReactionTest.php
index 5ab9037c..90036048 100644
--- a/tests/src/Functional/JsonldTypeAlterReactionTest.php
+++ b/tests/src/Functional/JsonldTypeAlterReactionTest.php
@@ -34,11 +34,11 @@ class JsonldTypeAlterReactionTest extends JsonldSelfReferenceReactionTest {
       ], 'Save and continue');
       $this->submitForm([], 'Save field settings');
     }
-    else {
+    elseif (version_compare(\Drupal::VERSION, '10.3.x-dev', 'lt'){
       $this->getSession()->getPage()->selectFieldOption('new_storage_type', 'plain_text');
       // First need to submit the form with the elements displayed
       // on initial page load. The form is using AJAX to send a second element
       // after we selected the radio button above
       // we can instead get the second element by submitting the form
       // and having it throw an error since the required field is missing.
       // @todo refactor this as a functional javascript test.
@@ -59,6 +59,25 @@ class JsonldTypeAlterReactionTest extends JsonldSelfReferenceReactionTest {
         'group_field_options_wrapper' => 'string',
       ], 'Continue');
     }
+    else {
+      $this->getSession()->getPage()->selectFieldOption('new_storage_type', 'plain_text');
+      // For Drupal 10.3 the label is not visible at first.
+      // @todo refactor this as a functional javascript test.
+      $this->submitForm([
+        'new_storage_type' => 'plain_text',
+      ], 'Continue');
+
+      // Now we can proceed, entering a label and selecting Text (plain)
+      // for the second element now that the elements are displayed after
+      // the initial form submission.
+      $this->getSession()->getPage()->selectFieldOption('group_field_options_wrapper', 'string');
+      $this->submitForm([
+        'new_storage_type' => 'plain_text',
+        'label' => 'Typed Predicate',
+        'field_name' => 'type_predicate',
+        'group_field_options_wrapper' => 'string',
+      ], 'Continue');
+    }
     $this->submitForm([], 'Save settings');
     $this->assertSession()->responseContains('field_type_predicate');
 
@@ -34,11 +34,11 @@ class JsonldTypeAlterReactionTest extends JsonldSelfReferenceReactionTest {
       $this->getSession()->getPage()->selectFieldOption('new_storage_type', 'plain_text');
-      // First need to submit the form with the elements displayed
-      // on initial page load. The form is using AJAX to send a second element
-      // after we selected the radio button above
+      // For Drupal 10.2, we first need to submit the form with the elements
+      // displayed on initial page load. The form is using AJAX to send a
+      // second element after we selected the radio button above
       // we can instead get the second element by submitting the form
       // and having it throw an error since the required field is missing.
